@@ -64,11 +64,9 @@ def insert(settings, body):
     data = atomic_file_action(action)
     pending = len([True for v in data.values() if v["status"] == "pending"])
     running = len([True for v in data.values() if v["status"] == "running"])
-    created = len([True for v in data.values() if v["status"] == "created"])
 
     data["pending"] = pending
     data["running"] = running
-    data["created"] = created
     return data
 
 
@@ -78,7 +76,7 @@ def insert_jobs_from_project(settings, project_id):
     try:
         for job in gl.projects.get(project_id, lazy=True).jobs.list(
             iterator=True,
-            scope=["created", "running", "pending"],
+            scope=["running", "pending"],
         ):
             body = {
                 "build_id": job.id,
